   function [DOMAIN, labl] = RSB(A, msteps, maxsets, indx) 
%% function [DOMAIN, labl] = RSB(A, msteps, maxsets, indx) 
%%
%% Input:
%% A        = Laplacean graph
%% msteps   = max numbers of Lanczos steps used in each reduction
%% maxsets  = max number of sets in all
%%            1, 3, , 15, 31, ... for exact levels 
%% indx     = indx array of size n - carried onto the subsets.
%%
%% Output:
%% 
%% DOMAIN   = array of structs containing a number of clusters -- 
%%          DOMAIN(i) = struct('indx',indx,'indx',lab);
%%                       k  = size of this cluster
%%                       Ac = Sub-Laplacean
%%                       indx = index array for Ac as inherited from indx
%% Note: redundancy: k can be removed (=size(Ac,2)). c can be removed
%% (c = sum(Ac,2)/k) 
%% 
 [n,m] = size(A);
 labl = ones(n,1);
 Set = struct('indx',indx);
 B = A;
 nsets = 1;
%%%
 maxsiz = n;
 outset = 1;
%%-------------------------------------------------------- 
while ((maxsiz>30) & nsets < maxsets) 
    nev = 2;
    [YY, lam] = Lan(B, nev, msteps, 'ascend');
%%## BEGIN WITH EIGS
%%   [YY, lam] = eigs(B, nev,'SA');
%%   [lam, iii] = sort(diag(lam),'ascend') ;
%%   nev = iii(nev);
%%%## END WITH EIGS
    Nloc = size(B,1);
    new = nsets+1;
    v = YY(:,nev);
    [t, kmed] = min(abs(v-median(v)));
    t = v(kmed);
    indm = []; indp = [];
%%------------
    ip = 0;
    im = 0;
    for i=1:Nloc
      if (v(i)<t)
       im = im+1;
       indm(im)=indx(i);
       labl(indx(i)) = outset;
      else 
       ip = ip+1;
       indp(ip)=indx(i);
       labl(indx(i)) = new;
     end
    end
    disp('setm sizm setp sizp')
    disp([outset,im,new,ip])  
%%-------------------- complete data for current node
%%-------------------- the two other 
    Setm=struct('indx',indm);
    Setp=struct('indx',indp);
    DOMAIN(outset) = Setm;
    DOMAIN(new) = Setp;
    nsets = new;
%%-------------------- select largest set split at the next step
    maxsiz = length(indp);
    outset = new;
    for i=1:nsets-1
          DomSiz = length(DOMAIN(i).indx);   
          if (DomSiz > maxsiz) 
              outset = i;
              maxsiz = DomSiz;
          end
    end
    disp('next set')
    disp(outset) 
    indx = DOMAIN(outset).indx;
%%-------------------- subgraph = 
    B = getMat(A,indx,labl);
end
%% 
for ii = 1:nsets
    fprintf(1,' dom %d size %d: \n',ii,length(DOMAIN(ii).indx))
end
